#!/bin/sh

# Usage:
#  Delayed recording:
#    $0 start_date stop_date quality URL outfile
#
#  Immediate recording:
#    $0 direct stop_date quality URL outfile
#
# When started, will generate a outfile.pid file containing the PID of
# the running process
#
# "Quality" is either "vlc_low" ou "vlc_high"

# Delayed recording: register a new "at" job
if [ x"$1" != xdirect ] ; then
    when="$1" ; shift
    secs=`date --date="$when" +%s`
    nows=$[`date +%s` + 10]

    if [ $secs -lt $nows ] ; then
        when=now
    fi

    # $0 direct $*
    cmd="'$0' direct"
    for c in "$@" ; do
	escaped=`echo "$c" | sed "s/'/\\\\\\'/g"`
	cmd="$cmd '$escaped'"
    done
    echo $cmd | at `date --date="$when" +"%H:%M %m/%d/%Y"`
    exit 0
fi

# Immediate recording
shift
START=`date +%s`
STOP=`date --date="$1" +%s` ; shift
QUALITY="$1" ; shift
STREAM="$1" ; shift
OUTFILE="$*"
STOP=$[$STOP + 1 * 60]
LENGTH=$[$STOP - $START]
PIDFILE="$OUTFILE".pid

# Do nothing for 0-length'ed recording
[ $LENGTH -lt 0 ] && exit -1

case x"$QUALITY" in
  xvlc_low)
    vlc $STREAM --filter deinterlace:bob --sout "#transcode{vcodec=mp1v,vb=512,scale=0.75,acodec=mpga,ab=96,channels=2}:std{access=file,mux=ps,url=$OUTFILE}" -I dummy &
    pid=$!
    ;;

  xvlc_high)
    vlc $STREAM --filter deinterlace:bob --sout "#std{access=file,mux=ts,url=$OUTFILE}" -I dummy &
    pid=$!
    ;;
  *)
    exit -1;;
esac

echo spawned $pid
echo -e $pid'\x0a'$$ > "$PIDFILE"

_trap_kill ()
{
    trap "" KILL EXIT QUIT INT TERM CHLD
    echo killing $pid
    kill $pid
    sleep 3
    rm -f "$PIDFILE"
    exit 0
}
trap _trap_kill KILL EXIT QUIT INT TERM CHLD

sleep $LENGTH

# Will call _trap_kill
exit 0
